@@ -1,7 +1,7 @@
 package Org::Element::List;
 
-our $DATE = '2020-12-30'; # DATE
-our $VERSION = '0.554'; # VERSION
+our $DATE = '2021-06-27'; # DATE
+our $VERSION = '0.555'; # VERSION
 
 use 5.010;
 use locale;
@@ -36,7 +36,7 @@ Org::Element::List - Represent Org list
 
 =head1 VERSION
 
-This document describes version 0.554 of Org::Element::List (from Perl distribution Org-Parser), released on 2020-12-30.
+This document describes version 0.555 of Org::Element::List (from Perl distribution Org-Parser), released on 2021-06-27.
 
 =head1 DESCRIPTION
 
@@ -82,7 +82,7 @@ Source repository is at L<https://github.com/perlancar/perl-Org-Parser>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Org-Parser/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-Parser>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -94,7 +94,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
